# Detection API

::: pretok.detection.base.LanguageDetector
    options:
      show_source: true

::: pretok.detection.base.DetectionResult

::: pretok.detection.fasttext.FastTextDetector

::: pretok.detection.langdetect.LangDetectDetector

::: pretok.detection.composite.CompositeDetector
